@@ -1,5 +1,5 @@
 package Resque::Worker;
-$Resque::Worker::VERSION = '0.18';
+$Resque::Worker::VERSION = '0.19';
 use Moose;
 with 'Resque::Encoder';
 
@@ -313,13 +313,20 @@ sub worker_pids {
     my $self = shift;
     my @pids;
 
-    my $ps_command = $^O eq 'solaris'
-                ? 'ps -A -o pid,args'
-                : 'ps -A -o pid,command';
+    if($^O=~m/^(cygwin|MSWin32)$/i) {
+        # $0 assignment does not work under Win32, so we'll return a list of perl PIDs instead
+        @pids = map { s/^PID:\s*// && $_ }
+                grep { /^PID/ }
+                split( /[\r\n]/ , `tasklist /FI "IMAGENAME eq perl.exe" /FO list` );
+    } else {
+        my $ps_command = $^O eq 'solaris'
+                    ? 'ps -A -o pid,args'
+                    : 'ps -A -o pid,command';
 
-    for ( split "\n", `$ps_command | grep resque | grep -v resque-web | grep -v grep` ) {
-        if ( m/^\s*(\d+)\s(.+)$/ ) {
-            push @pids, $1;
+        for ( split "\n", `$ps_command | grep resque | grep -v resque-web | grep -v grep` ) {
+            if ( m/^\s*(\d+)\s(.+)$/ ) {
+                push @pids, $1;
+            }
         }
     }
     return wantarray ? @pids : \@pids;
@@ -387,7 +394,7 @@ Resque::Worker - Does the hard work of babysitting Resque::Job's
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 ATTRIBUTES
 
@@ -613,7 +620,7 @@ Diego Kuperman <diego@freekeylabs.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Diego Kuperman.
+This software is copyright (c) 2015 by Diego Kuperman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
